﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Threading.Tasks;
using Microsoft.AspNetCore.Http;
using Microsoft.AspNetCore.Mvc;
using Microsoft.EntityFrameworkCore;
using Sales.Data;
using Sales.Data.Model;

namespace Sales.API.Controllers
{
    [Route("api/[controller]")]
    [ApiController]
    public class SalesController : ControllerBase
    {
        private readonly SalesContext _context;

        public SalesController(SalesContext context)
        {
            _context = context;
        }

        // GET: api/Sales
        [HttpGet]
        public async Task<ActionResult<IEnumerable<SalesFact>>> GetSalesFact()
        {
            return await _context.SalesFact.OrderBy(s => s.Date).ToListAsync();
        }

        // GET: api/Sales/5
        [HttpGet("{id}")]
        public async Task<ActionResult<SalesFact>> GetSalesFact(long id)
        {
            var salesFact = await _context.SalesFact.FindAsync(id);

            if (salesFact == null)
            {
                return NotFound();
            }

            return salesFact;
        }

        // PUT: api/Sales/5
        [HttpPut("{id}")]
        public async Task<IActionResult> PutSalesFact(long id, SalesFact salesFact)
        {
            if (id != salesFact.Id)
            {
                return BadRequest();
            }

            _context.Entry(salesFact).State = EntityState.Modified;

            try
            {
                await _context.SaveChangesAsync();
            }
            catch (DbUpdateConcurrencyException)
            {
                if (!SalesFactExists(id))
                {
                    return NotFound();
                }
                else
                {
                    throw;
                }
            }

            return NoContent();
        }

        // POST: api/Sales
        [HttpPost]
        public async Task<ActionResult<SalesFact>> PostSalesFact(SalesFact salesFact)
        {
            _context.SalesFact.Add(salesFact);
            await _context.SaveChangesAsync();

            return CreatedAtAction("GetSalesFact", new { id = salesFact.Id }, salesFact);
        }

        // DELETE: api/Sales/5
        [HttpDelete("{id}")]
        public async Task<ActionResult<SalesFact>> DeleteSalesFact(long id)
        {
            var salesFact = await _context.SalesFact.FindAsync(id);
            if (salesFact == null)
            {
                return NotFound();
            }

            _context.SalesFact.Remove(salesFact);
            await _context.SaveChangesAsync();

            return salesFact;
        }

        private bool SalesFactExists(long id)
        {
            return _context.SalesFact.Any(e => e.Id == id);
        }
    }
}
