﻿using System;
using System.Collections.Generic;
using System.Diagnostics;
using System.Linq;
using System.Net.Http;
using System.Threading.Tasks;
using Microsoft.AspNetCore.Mvc;
using Microsoft.Extensions.Configuration;
using Microsoft.PowerBI.Api.V2;
using Microsoft.PowerBI.Api.V2.Models;
using Microsoft.Rest;
using Newtonsoft.Json;
using SalesMvcApp.Models;

namespace SalesMvcApp.Controllers
{
    public class HomeController : Controller
    {
        private static bool configInitialized = false;
        private static string AuthorityUrl;
        private static string ResourceUrl;
        private static string ApplicationId;
        private static string ApplicationSecret;
        private static string ApiUrl;
        private static string WorkspaceId;
        private static string ReportId;
        private static string DatasetId;

        private static string MasterUsername;
        private static string MasterPassword;

        readonly IConfiguration _config;
        public HomeController(IConfiguration config)
        {
            this._config = config;
            InitConfigValues();
        }

        private void InitConfigValues()
        {
            if (!configInitialized)
            {
                AuthorityUrl = _config.GetSection("PowerBI").GetValue<string>("AuthorityUrl");
                ResourceUrl = _config.GetSection("PowerBI").GetValue<string>("ResourceUrl");
                ApplicationId = _config.GetSection("PowerBI").GetValue<string>("ApplicationId");
                ApplicationSecret = _config.GetSection("PowerBI").GetValue<string>("ApplicationSecret");
                ApiUrl = _config.GetSection("PowerBI").GetValue<string>("ApiUrl");
                WorkspaceId = _config.GetSection("PowerBI").GetValue<string>("WorkspaceId");
                ReportId = _config.GetSection("PowerBI").GetValue<string>("ReportId");
                DatasetId = _config.GetSection("PowerBI").GetValue<string>("DatasetId");
                MasterUsername = _config.GetSection("PowerBI").GetValue<string>("MasterUserId");
                MasterPassword = _config.GetSection("PowerBI").GetValue<string>("MasterUserPassword");
            }
        }


        public IActionResult Index()
        {
            EmbedConfig report = null;
            var proUserToken = AuthenticateAsync().GetAwaiter().GetResult();
            List<EffectiveIdentity> filters = new List<EffectiveIdentity>();
            filters.Add(new EffectiveIdentity
            {
                Username = "briannoyes",
                Roles = new List<string> { "Permissions" },
                Datasets = new List<string> { DatasetId }
            });
            report = GenerateReport(proUserToken.AccessToken, filters);

            return View(report);
        }

        private async Task<OAuthResult> AuthenticateAsync()
        {
            var oauthEndpoint = new Uri(AuthorityUrl);

            using (var client = new HttpClient())
            {
                var result = await client.PostAsync(oauthEndpoint, new FormUrlEncodedContent(new[]
                    {
                    new KeyValuePair<string,string>("resource", ResourceUrl),
                    new KeyValuePair<string,string>("client_id", ApplicationId),
                    new KeyValuePair<string,string>("client_secret", ApplicationSecret),
                    new KeyValuePair<string,string>("grant_type", "password"),
                    new KeyValuePair<string,string>("username", MasterUsername),
                    new KeyValuePair<string,string>("password", MasterPassword),
                    new KeyValuePair<string,string>("scope", "openid")
                }
                ));

                var content = await result.Content.ReadAsStringAsync();
                return JsonConvert.DeserializeObject<OAuthResult>(content);
            }
        }

        private EmbedConfig GenerateReport(string token, List<EffectiveIdentity> filters = null)
        {
            EmbedConfig config = null;
            var tokenCredentials = new TokenCredentials(token, "Bearer");

            // Create a Power BI Client object. It will be used to call Power BI APIs.
            using (var client = new PowerBIClient(new Uri("https://api.powerbi.com"), tokenCredentials))
            {
                Report report = client.Reports.GetReportInGroup(WorkspaceId, ReportId);
                if (report != null)
                {
                    var requestParameters = new GenerateTokenRequest();
                    requestParameters.AccessLevel = "View";
                    if (filters != null)
                    {
                        requestParameters.Identities = filters;
                    }

                    // Generate EmbedToken This function sends the POST message 
                    //with all parameters and returns the token
                    EmbedToken embedtoken = client.Reports.GenerateTokenInGroupAsync(
                        WorkspaceId,
                        ReportId,
                        requestParameters).GetAwaiter().GetResult();

                    config = new EmbedConfig();
                    config.EmbedURL = report.EmbedUrl;
                    config.GroupID = WorkspaceId;
                    config.ReportData = report;
                    config.ReportID = ReportId;
                    config.Token = embedtoken?.Token;
                    config.TokenID = embedtoken?.TokenId;
                    config.Expiration = embedtoken?.Expiration;
                }

            }
            return config;
        }


        public IActionResult Privacy()
        {
            return View();
        }

        [ResponseCache(Duration = 0, Location = ResponseCacheLocation.None, NoStore = true)]
        public IActionResult Error()
        {
            return View(new ErrorViewModel { RequestId = Activity.Current?.Id ?? HttpContext.TraceIdentifier });
        }
    }




}
