import { Component, OnInit, ViewChild, Output, EventEmitter } from '@angular/core';
import { ModalDirective } from 'ngx-bootstrap/modal';
import { Sale } from '../model/sale';
import { HttpClient } from '@angular/common/http';
import { Constants } from '../constants';
import { Product, Segment, Country } from '../model/lookups';

@Component({
  selector: 'app-add-edit-sale',
  templateUrl: 'add-edit-sale.component.html',
  styleUrls: ['./add-edit-sale.component.scss']
})

export class AddEditSaleComponent implements OnInit {
  @ViewChild('addEditSaleModal')
  public addEditSaleModal: ModalDirective;
  @Output() saved = new EventEmitter();
  sale = new Sale();
  products: Product[];
  segments: Segment[];
  countries: Country[];

  editMode = false;
  error = '';

  constructor(private httpClient: HttpClient) { }

  ngOnInit() {
    this.httpClient.get<any>(`${Constants.apiRoot}Lookups`).subscribe(lookups => {
      this.products = lookups.products;
      this.segments = lookups.segments;
      this.countries = lookups.countries;
    });

  }

  show(sale: Sale = null) {
    this.editMode = !!sale;
    this.sale = sale;
    if (!this.sale) { this.sale = new Sale(); }
    this.addEditSaleModal.show();
  }

  save() {
    this.error = '';
    if (!this.sale.date) { this.error = 'Please enter a sale date.'; }
    else if (!this.sale.productId) { this.error = 'Please select a product.'; }
    else if (!this.sale.segmentId) { this.error = 'Please select a segment.'; }
    else if (!this.sale.countryId) { this.error = 'Please select a country.'; }
    else if (isNaN(this.sale.sales)) { this.error = 'Please enter a sale total.'; }
    else if (isNaN(this.sale.cogs)) { this.error = 'Please enter a COGS amount.'; }
    else if (isNaN(this.sale.profit)) { this.error = 'Please enter a profit amount.'; }
    else if (isNaN(this.sale.unitsSold)) { this.error = 'Please enter a value for units sold.'; }
    else {
      if (this.editMode) {
        this.httpClient.put<Sale>(`${Constants.apiRoot}Sales/${this.sale.id}`, this.sale).subscribe(() => {
          this.addEditSaleModal.hide();
          this.saved.next();
        });
      }
      else  {
        this.httpClient.post<Sale>(`${Constants.apiRoot}Sales`, this.sale).subscribe(sale => {
          this.addEditSaleModal.hide();
          this.saved.next();
        });
      }
    }
  }
}
