import { Component, OnInit, EventEmitter, ViewChild } from '@angular/core';
import { HttpClient } from '@angular/common/http';
import { Product, Segment, Country } from '../model/lookups';
import { Sale } from '../model/sale';
import { Constants } from '../constants';
import { AddEditSaleComponent } from './add-edit-sale.component';

@Component({
  selector: 'app-sales-list',
  templateUrl: 'sales-list.component.html',
  styleUrls: ['./sales-list.component.scss']
})

export class SalesListComponent implements OnInit {
  @ViewChild('addEditSaleModal') addEditSaleModal: AddEditSaleComponent;
  sales: Sale[];
  products: Product[];
  segments: Segment[];
  countries: Country[];

  constructor(private httpClient: HttpClient) { }

  ngOnInit() {
    this.refreshData();
  }

  onEditComplete($event) {
    const data = $event.data;
    data.sales = parseInt(data.sales, 10);
    this.httpClient.put<Sale>(`${Constants.apiRoot}Sales/${$event.data.id}`, $event.data).subscribe(() => {

    });
  }

  addSale() {
    this.addEditSaleModal.show();
  }

  edit(sale: Sale) {
    this.addEditSaleModal.show(sale);
  }

  refreshData() {
    this.httpClient.get<any>(`${Constants.apiRoot}Lookups`).subscribe(lookups => {
      this.products = lookups.products;
      this.segments = lookups.segments;
      this.countries = lookups.countries;
      this.httpClient.get<Sale[]>(`${Constants.apiRoot}Sales`).subscribe(sales => {
        sales.forEach(s => {
          s.date = new Date(s.date);
          s.product = this.products.find(p => p.id === s.productId).name;
          s.segment = this.segments.find(p => p.id === s.segmentId).name;
          s.country = this.countries.find(p => p.id === s.countryId).name;
        });
        this.sales = sales;
      });
    });
  }
}
